package com.xinelu.manage.mapper.projectdevice;

import com.xinelu.manage.domain.projectdevice.ProjectDevice;
import java.util.List;


/**
 * 检测项目设备Mapper接口
 *
 * @author haown
 * @date 2024-03-11
 */
public interface ProjectDeviceMapper {
    /**
     * 查询检测项目设备
     *
     * @param id 检测项目设备主键
     * @return 检测项目设备
     */
    public ProjectDevice selectProjectDeviceById(Long id);

    /**
     * 查询检测项目设备列表
     *
     * @param projectDevice 检测项目设备
     * @return 检测项目设备集合
     */
    public List<ProjectDevice> selectProjectDeviceList(ProjectDevice projectDevice);

    /**
     * 新增检测项目设备
     *
     * @param projectDevice 检测项目设备
     * @return 结果
     */
    public int insertProjectDevice(ProjectDevice projectDevice);

    /**
     * 修改检测项目设备
     *
     * @param projectDevice 检测项目设备
     * @return 结果
     */
    public int updateProjectDevice(ProjectDevice projectDevice);

    /**
     * 删除检测项目设备
     *
     * @param id 检测项目设备主键
     * @return 结果
     */
    public int deleteProjectDeviceById(Long id);

    /**
     * 批量删除检测项目设备
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProjectDeviceByIds(Long[] ids);
}
